import type { Either } from '@lokalise/node-core';
import type { BarrierResult, Prehandler, PrehandlingOutputs, QueueConsumer, QueueConsumerOptions } from '@message-queue-toolkit/core';
import type { Connection, Message } from 'amqplib';
import type { AMQPConsumerDependencies, AMQPLocator, AMQPCreationConfig } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPConsumerOptions<MessagePayloadType extends object, ExecutionContext = undefined, PrehandlerOutput = undefined> = QueueConsumerOptions<AMQPCreationConfig, AMQPLocator, MessagePayloadType, ExecutionContext, PrehandlerOutput>;
export declare abstract class AbstractAmqpConsumer<MessagePayloadType extends object, ExecutionContext, PrehandlerOutput = undefined> extends AbstractAmqpService<MessagePayloadType, AMQPConsumerDependencies, ExecutionContext, PrehandlerOutput> implements QueueConsumer {
    private readonly transactionObservabilityManager?;
    private readonly errorResolver;
    private readonly messageSchemaContainer;
    private readonly handlerContainer;
    private readonly executionContext;
    constructor(dependencies: AMQPConsumerDependencies, options: AMQPConsumerOptions<MessagePayloadType, ExecutionContext, PrehandlerOutput>, executionContext: ExecutionContext);
    start(): Promise<void>;
    receiveNewConnection(connection: Connection): Promise<void>;
    private consume;
    private internalProcessMessage;
    protected processMessage(message: MessagePayloadType, messageType: string, prehandlingOutputs: PrehandlingOutputs<PrehandlerOutput, any>): Promise<Either<'retryLater', 'success'>>;
    protected processPrehandlers(message: MessagePayloadType, messageType: string): Promise<PrehandlerOutput>;
    protected preHandlerBarrier<BarrierOutput>(message: MessagePayloadType, messageType: string, prehandlerOutput: PrehandlerOutput): Promise<BarrierResult<BarrierOutput>>;
    protected resolveSchema(message: MessagePayloadType): Either<Error, import("zod").ZodType<MessagePayloadType, import("zod").ZodTypeDef, MessagePayloadType>>;
    protected resolveMessageLog(message: MessagePayloadType, messageType: string): unknown;
    protected resolveNextFunction(prehandlers: Prehandler<MessagePayloadType, ExecutionContext, unknown>[], message: MessagePayloadType, index: number, prehandlerOutput: PrehandlerOutput, resolve: (value: PrehandlerOutput | PromiseLike<PrehandlerOutput>) => void, reject: (err: Error) => void): (prehandlerResult: import("@message-queue-toolkit/core/dist/lib/queues/HandlerContainer").PrehandlerResult) => void;
    private deserializeMessage;
    private tryToExtractId;
    protected resolveMessage(message: Message): Either<import("@message-queue-toolkit/core").MessageInvalidFormatError | import("@message-queue-toolkit/core").MessageValidationError, unknown>;
}
