import type { Either } from '@lokalise/node-core';
import type { BarrierResult, MessageInvalidFormatError, MessageValidationError, QueuePublisherOptions, SyncPublisher } from '@message-queue-toolkit/core';
import type { ZodSchema } from 'zod';
import type { AMQPLocator, AMQPCreationConfig, AMQPDependencies } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPPublisherOptions<MessagePayloadType extends object> = QueuePublisherOptions<AMQPCreationConfig, AMQPLocator, MessagePayloadType>;
export declare abstract class AbstractAmqpPublisher<MessagePayloadType extends object> extends AbstractAmqpService<MessagePayloadType> implements SyncPublisher<MessagePayloadType> {
    private readonly messageSchemaContainer;
    constructor(dependencies: AMQPDependencies, options: AMQPPublisherOptions<MessagePayloadType>);
    publish(message: MessagePayloadType): void;
    protected resolveSchema(message: MessagePayloadType): Either<Error, ZodSchema<MessagePayloadType>>;
    protected resolveMessage(): Either<MessageInvalidFormatError | MessageValidationError, unknown>;
    protected processPrehandlers(): Promise<unknown>;
    protected preHandlerBarrier<BarrierOutput>(): Promise<BarrierResult<BarrierOutput>>;
    protected resolveNextFunction(): () => void;
    processMessage(): Promise<Either<'retryLater', 'success'>>;
}
