import type { QueueConsumerDependencies, QueueDependencies, QueueOptions } from '@message-queue-toolkit/core';
import { AbstractQueueService } from '@message-queue-toolkit/core';
import type { Channel, Connection, Message } from 'amqplib';
import type { Options } from 'amqplib/properties';
import type { AmqpConnectionManager, ConnectionReceiver } from './AmqpConnectionManager';
export type AMQPDependencies = QueueDependencies & {
    amqpConnectionManager: AmqpConnectionManager;
};
export type AMQPConsumerDependencies = AMQPDependencies & QueueConsumerDependencies;
export type AMQPQueueConfig = Options.AssertQueue;
export type AMQPCreationConfig = {
    queueOptions: AMQPQueueConfig;
    queueName: string;
    updateAttributesIfExists?: boolean;
};
export type AMQPLocator = {
    queueName: string;
};
export declare abstract class AbstractAmqpService<MessagePayloadType extends object, DependenciesType extends AMQPDependencies = AMQPDependencies, ExecutionContext = unknown, PrehandlerOutput = unknown> extends AbstractQueueService<MessagePayloadType, Message, DependenciesType, AMQPCreationConfig, AMQPLocator, QueueOptions<AMQPCreationConfig, AMQPLocator>, ExecutionContext, PrehandlerOutput> implements ConnectionReceiver {
    protected connection?: Connection;
    private connectionManager;
    protected channel: Channel;
    private isShuttingDown;
    protected readonly queueName: string;
    constructor(dependencies: DependenciesType, options: QueueOptions<AMQPCreationConfig, AMQPLocator>);
    receiveNewConnection(connection: Connection): Promise<void>;
    private checkQueueExists;
    private destroyChannel;
    init(): Promise<void>;
    reconnect(): Promise<void>;
    close(): Promise<void>;
}
