"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveAmqpConnection = void 0;
const promises_1 = require("timers/promises");
const node_core_1 = require("@lokalise/node-core");
const amqplib_1 = require("amqplib");
const CONNECT_RETRY_SECONDS = 10;
const MAX_RETRY_ATTEMPTS = 10;
async function resolveAmqpConnection(config) {
    const protocol = config.useTls ? 'amqps' : 'amqp';
    let counter = 0;
    // eslint-disable-next-line no-constant-condition
    while (true) {
        const url = `${protocol}://${config.username}:${config.password}@${config.hostname}:${config.port}/${config.vhost}`;
        const retryTime = CONNECT_RETRY_SECONDS * 1000 * (counter + 1);
        try {
            const connection = await (0, amqplib_1.connect)(url);
            return connection;
        }
        catch (e) {
            node_core_1.globalLogger.error(`Failed to connect to AMQP broker at ${config.hostname}:${config.port}. Retrying in ${retryTime / 1000} seconds...`);
        }
        await (0, promises_1.setTimeout)(retryTime);
        counter++;
        if (counter > MAX_RETRY_ATTEMPTS) {
            throw new Error('Failed to resolve AMQP connection');
        }
    }
}
exports.resolveAmqpConnection = resolveAmqpConnection;
//# sourceMappingURL=amqpConnectionResolver.js.map